@@ -1,16 +1,5 @@
 context("Dimethenamid data from 2018")
 
-# Data
-dmta_ds <- lapply(1:7, function(i) {
-  ds_i <- dimethenamid_2018$ds[[i]]$data
-  ds_i[ds_i$name == "DMTAP", "name"] <-  "DMTA"
-  ds_i$time <- ds_i$time * dimethenamid_2018$f_time_norm[i]
-  ds_i
-})
-names(dmta_ds) <- sapply(dimethenamid_2018$ds, function(ds) ds$title)
-dmta_ds[["Elliot"]] <- rbind(dmta_ds[["Elliot 1"]], dmta_ds[["Elliot 2"]])
-dmta_ds[["Elliot 1"]] <- dmta_ds[["Elliot 2"]] <- NULL
-
 test_that("Different backends get consistent results for DFOP tc, dimethenamid data", {
 
   skip_on_cran() # Time constraints
@@ -85,7 +74,8 @@ sfo_sfo3p <- mkinmod(
 )
 
 dmta_sfo_sfo3p_tc <- mmkin(list("SFO-SFO3+" = sfo_sfo3p),
-  dmta_ds, error_model = "tc", quiet = TRUE, cores = n_cores)
+  dmta_ds, error_model = "tc", quiet = TRUE,
+  cores = n_cores)
 
 test_that("Different backends get consistent results for SFO-SFO3+, dimethenamid data", {
 
