@@ -5,13 +5,12 @@ test_that("Simple temperature and moisture normalisation works", {
 })
 
 test_that("Time step normalisation for a dataset works", {
-  expect_output(f_time_norm_focus(D24_2014, study_moisture_ref_source = "focus", f_na = 1),
-    "was set to")
+  expect_message(f_time_norm_focus(D24_2014, study_moisture_ref_source = "focus", f_na = 1))
   expect_equal(round(D24_2014$f_time_norm, 3), c(1.606, 0.712, 0.716, 0.716, 0.898))
-  expect_output(f_time_norm_focus(dimethenamid_2018), "was set to")
+  expect_message(f_time_norm_focus(dimethenamid_2018))
 
   # Reference values from Dimethenamid RAR 2018 Vol3 B.8
-  expect_equal(round(dimethenamid_2018$f_time_norm, 3), 
+  expect_equal(round(dimethenamid_2018$f_time_norm, 3),
     c(1,
       0.971,                           # p. 56
       rep(round(1.329 * 0.924, 3), 2), # p. 51
